searchData={"items":[{"type":"behaviour","title":"SwissSchema","doc":"`SwissSchema` is a query toolkit for Ecto schemas. It makes it easy to manipulate data using Ecto schemas by implementing relevant Ecto.Repo [Query API](https://hexdocs.pm/ecto/Ecto.Repo.html#query-api) and [Schema API](https://hexdocs.pm/ecto/Ecto.Repo.html#schema-api) functions, pre-configured to work specifically with the given Ecto schema.","ref":"SwissSchema.html"},{"type":"behaviour","title":"Setup - SwissSchema","doc":"Add `swiss_schema` as a dependency in `mix.exs`:\n\n    def deps do\n    [\n      # ...\n      {:swiss_schema, \"~> 0.6\"}\n    ]\n    end\n\nThen, `use SwissSchema` in your Ecto schemas:\n\n    # lib/my_app/accounts/user.ex\n\n    defmodule MyApp.Accounts.User do\n      use Ecto.Schema\n      use SwissSchema, repo: MyApp.Repo\n\n      def changeset(%__MODULE__{} = user, params) do\n        # Set up your schema's default changeset here\n      end\n    end\n\nThat's it, you should be good to go.","ref":"SwissSchema.html#module-setup"},{"type":"behaviour","title":"Usage - SwissSchema","doc":"After setting up SwissSchema in your Ecto schema, there isn't much else to do. Just use the available functions now available in your own schema module:\n\n    iex> alias MyApp.Accounts.User\n\n    iex> User.all()\n    []\n\n    iex> User.create(%{name: \"John Smith\", email: \"john@smiths.net\"})\n    {:ok, %User%{name: \"John Smith\", ...}}\n\n    iex> User.all()\n    [%User%{name: \"John Smith\", ...}]\n\n`SwissSchema` functions tries to mimic the Ecto.Repo's Query and Repo APIs by acting as a thin, pre-configured interface for Ecto.Repo callbacks.\n\n> ##","ref":"SwissSchema.html#module-usage"},{"type":"behaviour","title":"Note {: .info} - SwissSchema","doc":">\n> To keep examples simple and short, we use the example module above, `MyApp.Accounts.User`, through the documentation. So, when reading the docs for SwissSchema functions, assume the following alias was previously set up:\n>\n>     alias MyApp.Accounts.User\n>\n> So, `MyApp.Accounts.User` will be referred to as `User`.","ref":"SwissSchema.html#module-note-info"},{"type":"callback","title":"SwissSchema.aggregate/2","doc":"Calculate the given aggregation.","ref":"SwissSchema.html#c:aggregate/2"},{"type":"callback","title":"Examples - SwissSchema.aggregate/2","doc":"# Returns the number of users\n    User.aggregate(:count)\n\n    # Set a timeout of 60s\n    User.aggregate(:count, timeout: 60_000)\n\n> See Ecto's [`aggregate/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:aggregate/3) for extensive info.","ref":"SwissSchema.html#c:aggregate/2-examples"},{"type":"callback","title":"SwissSchema.aggregate/3","doc":"Calculate the given `aggregate` over the given `field`.","ref":"SwissSchema.html#c:aggregate/3"},{"type":"callback","title":"Examples - SwissSchema.aggregate/3","doc":"# Returns the sum of the number of visits for every user\n    User.aggregate(:sum, :visits)\n\n    # Returns the average number of user visits\n    User.aggregate(:avg, :visits)\n\n> See Ecto's [`aggregate/4`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:aggregate/4) for extensive info.","ref":"SwissSchema.html#c:aggregate/3-examples"},{"type":"callback","title":"SwissSchema.all/1","doc":"Fetches all entries from the respective data store.","ref":"SwissSchema.html#c:all/1"},{"type":"callback","title":"Examples - SwissSchema.all/1","doc":"# Fetch all users\n    User.all()\n\n> See Ecto's [`all/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:all/2) for extensive info.","ref":"SwissSchema.html#c:all/1-examples"},{"type":"callback","title":"SwissSchema.changeset/2","doc":"Defines the default changeset function.\n\nThis callback is used by database-touching functions to validate changes.","ref":"SwissSchema.html#c:changeset/2"},{"type":"callback","title":"Examples - SwissSchema.changeset/2","doc":"User.changeset(%User{}, %{name: \"John\"})\n    iex> %Ecto.Changeset{valid?: true}\n\n> See Ecto's [`Ecto.Changeset`](https://hexdocs.pm/ecto/Ecto.Changeset.html) for extensive info.","ref":"SwissSchema.html#c:changeset/2-examples"},{"type":"callback","title":"SwissSchema.create/2","doc":"Creates a new struct.\n\n`c:create/2` accepts a key-value map, validates it against the schema's `changeset/2`, and inserts into the repository if the validation succeeds.","ref":"SwissSchema.html#c:create/2"},{"type":"callback","title":"Examples - SwissSchema.create/2","doc":"# Returns an :ok tuple with valid params\n    {:ok, user} = User.create(%{name: \"John S.\", email: \"john@smiths.net\"})\n\n    # Returns an :error tuple with invalid params\n    {:error, %Ecto.Changeset{...}} = User.create(%{name: 123, email: \"john\"})","ref":"SwissSchema.html#c:create/2-examples"},{"type":"callback","title":"SwissSchema.create!/2","doc":"Same as `c:create/2` but returns the struct or raises if parameters are invalid.","ref":"SwissSchema.html#c:create!/2"},{"type":"callback","title":"SwissSchema.delete/2","doc":"Deletes an entry using its primary key.\n\nIt returns `{:ok, struct}` if the entry has been successfully deleted or `{:error, changeset}` if there was a validation or a known constraint error.","ref":"SwissSchema.html#c:delete/2"},{"type":"callback","title":"Examples - SwissSchema.delete/2","doc":"user = User.get!(42)\n\n    case User.delete user do\n      {:ok, user}         -> # Deleted with success\n      {:error, changeset} -> # Something went wrong\n    end\n\n> See Ecto's [`delete/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:delete/2) for extensive info.","ref":"SwissSchema.html#c:delete/2-examples"},{"type":"callback","title":"SwissSchema.delete!/2","doc":"Same as `c:delete/2` but returns the entry, or raises.","ref":"SwissSchema.html#c:delete!/2"},{"type":"callback","title":"Examples - SwissSchema.delete!/2","doc":"user = User.get!(42)\n\n    User.delete user do\n      {:ok, user}         -> # Deleted with success\n      {:error, changeset} -> # Something went wrong\n    end\n\n> See Ecto's [`delete!/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:delete!/2) for extensive info.","ref":"SwissSchema.html#c:delete!/2-examples"},{"type":"callback","title":"SwissSchema.delete_all/1","doc":"Deletes all entries.\n\nIt returns a two-values tuple: the number of entries deleted, and `nil`.","ref":"SwissSchema.html#c:delete_all/1"},{"type":"callback","title":"Examples - SwissSchema.delete_all/1","doc":"User.delete_all()\n\n> See Ecto's [`delete_all/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:delete_all/2) for extensive info.","ref":"SwissSchema.html#c:delete_all/1-examples"},{"type":"callback","title":"SwissSchema.get/2","doc":"Fetches an entry by the primary key.\n\nIt returns `{:ok, entry}` if the entry is found, or `{:error, :not_found}` otherwise.","ref":"SwissSchema.html#c:get/2"},{"type":"callback","title":"Examples - SwissSchema.get/2","doc":"iex> User.get(1)\n    {:ok, %User{}}\n\n    iex> User.get(1234567890)\n    {:error, :not_found}\n\n> See Ecto's [`get/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:get/3) for extensive info.","ref":"SwissSchema.html#c:get/2-examples"},{"type":"callback","title":"SwissSchema.get!/2","doc":"Similar to `c:get/2` but raises `Ecto.NoResultsError` if no entry was found.","ref":"SwissSchema.html#c:get!/2"},{"type":"callback","title":"Examples - SwissSchema.get!/2","doc":"iex> User.get!(1)\n    %User{}\n\n    iex> User.get!(1234567890)\n    ** (Ecto.NoResultsError) expected at least one result but got none in query\n\n> See Ecto's [`get!/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:get!/3) for extensive info.","ref":"SwissSchema.html#c:get!/2-examples"},{"type":"callback","title":"SwissSchema.get_by/2","doc":"Fetches a single entry by using a keyword list of clauses.\n\nIt returns a single matching entry as `{:ok, entry}`, or `{:error, :not_found}` when none is found.","ref":"SwissSchema.html#c:get_by/2"},{"type":"callback","title":"Examples - SwissSchema.get_by/2","doc":"iex> User.get_by(email: \"john@smiths.net\")\n    %User{}\n\n> See Ecto's [`get_by/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:get_by/3) for extensive info.","ref":"SwissSchema.html#c:get_by/2-examples"},{"type":"callback","title":"SwissSchema.get_by!/2","doc":"Similar to `c:get_by/2` but raises `Ecto.NoResultsError` if no entry is found, or `Ecto.MultipleResultsError` if multiple entries are found.","ref":"SwissSchema.html#c:get_by!/2"},{"type":"callback","title":"Examples - SwissSchema.get_by!/2","doc":"iex> User.get_by!(email: \"john@smiths.net\")\n    %User{}\n\n    iex> User.get_by!(email: \"nobody@localhost\")\n    ** (Ecto.NoResultsError)\n\n    iex> User.get_by!(first_name: \"John\")\n    ** (Ecto.MultipleResultsError)\n\n> See Ecto's [`get_by!/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:get_by!/3) for extensive info.","ref":"SwissSchema.html#c:get_by!/2-examples"},{"type":"callback","title":"SwissSchema.insert/2","doc":"Inserts a new entry.\n\nAccepts a map with key-values matching respective schema fields.\n\nIt returns `{:ok, struct}` if the entry has been successfully inserted, or\n`{:error, %Ecto.Changeset{}}` if there is a validation or a known constraint error.","ref":"SwissSchema.html#c:insert/2"},{"type":"callback","title":"Examples - SwissSchema.insert/2","doc":"A typical example is calling `c:insert/2` with a map and acting on the\nreturn value:\n\n    case User.insert(%{name: \"John S.\", email: \"john@smiths.net\"}) do\n      {:ok, user}         -> # Inserted with success\n      {:error, changeset} -> # Something went wrong\n    end\n\n> See Ecto's [`insert/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert/2) for extensive info.","ref":"SwissSchema.html#c:insert/2-examples"},{"type":"callback","title":"SwissSchema.insert!/2","doc":"Same as `c:insert/2` but returns the struct or raises if the changeset is invalid.","ref":"SwissSchema.html#c:insert!/2"},{"type":"callback","title":"SwissSchema.insert_all/2","doc":"Inserts all entries into the repository.","ref":"SwissSchema.html#c:insert_all/2"},{"type":"callback","title":"Examples - SwissSchema.insert_all/2","doc":"User.insert_all([ [name: \"John S.\"], [name: \"Jane S.\"] ])\n\n    User.insert_all([ %{name: \"John S.\"}, %{name: \"Jane S.\"} ])\n\n> See Ecto's [`insert_all/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert_all/3) for extensive info.","ref":"SwissSchema.html#c:insert_all/2-examples"},{"type":"callback","title":"SwissSchema.insert_or_update/2","doc":"Inserts or updates a changeset depending on whether the struct is persisted or not.","ref":"SwissSchema.html#c:insert_or_update/2"},{"type":"callback","title":"Examples - SwissSchema.insert_or_update/2","doc":"iex> User.changeset(%User{}, %{name: \"John S.\", email: \"john@smiths.net\"})\n         |> User.insert_or_update()\n    {:ok, %User{}}\n\n    User.get_by!(email: \"john@smiths.net\")\n    |> User.changeset(%{email: \"john.s@smiths.net\"})\n    |> User.insert_or_update()\n\n> See Ecto's [`insert_or_update/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert_or_update/2) for extensive info.","ref":"SwissSchema.html#c:insert_or_update/2-examples"},{"type":"callback","title":"SwissSchema.insert_or_update!/2","doc":"Same as `c:insert_or_update/2` but returns the struct or raises if parameters are invalid.\n\n> See Ecto's [`insert_or_update!/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert_or_update!/2) for extensive info.","ref":"SwissSchema.html#c:insert_or_update!/2"},{"type":"callback","title":"SwissSchema.stream/1","doc":"Returns a lazy enumerable that emits all entries from the data store.\n\n> See Ecto's [`stream/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:stream/2) for extensive info.","ref":"SwissSchema.html#c:stream/1"},{"type":"callback","title":"SwissSchema.update/3","doc":"Updates a struct.","ref":"SwissSchema.html#c:update/3"},{"type":"callback","title":"Examples - SwissSchema.update/3","doc":"iex> User.get_by!(email: \"john@smiths.net\")\n         |> User.update(%{email: \"john.s@smiths.net\"})\n    {:ok, %User{}}\n\n> See Ecto's [`update/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:update/2) for extensive info.","ref":"SwissSchema.html#c:update/3-examples"},{"type":"callback","title":"SwissSchema.update!/3","doc":"Same as `c:update/3` but returns the struct or raises if parameters are invalid.","ref":"SwissSchema.html#c:update!/3"},{"type":"callback","title":"Examples - SwissSchema.update!/3","doc":"iex> User.get_by!(email: \"john@smiths.net\")\n         |> User.update!(%{email: \"john.s@smiths.net\"})\n    %User{}\n\n> See Ecto's [`update!/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:update!/2) for extensive info.","ref":"SwissSchema.html#c:update!/3-examples"},{"type":"callback","title":"SwissSchema.update_all/2","doc":"Updates all entries matching the given query with the given values.","ref":"SwissSchema.html#c:update_all/2"},{"type":"callback","title":"Examples - SwissSchema.update_all/2","doc":"iex> User.update_all(set: [is_active: false])\n\n    iex> User.update_all(inc: [age: 1])\n\n> See Ecto's [`update_all/3`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:update_all/3) for extensive info.","ref":"SwissSchema.html#c:update_all/2-examples"}],"content_type":"text/markdown"}